function Output = EIKOexample06(N)
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function Output = EIKOexample06(N)
% ____________________________________________________________________________
% 18.311 (Principles of Applied Mathematics). MIT, Winter 2008. R. R. Rosales.
%
% Provides the data needed to make a plot for the evolution of a wave-front by
% the Eikonal equation (Phi_x)^2 + (Phi_y)^2 = 1 (motion at unit speed, normal
% to the wavefront.)
%
% When N = 0, it should print on the screen a short description of the example
%             and then quit (no output.)
%
% When no input is given, it should provide the structure Output ---- with the
% data needed for the plots. Output must have the fields:
%
% exa .......... String with example number.
% txt .......... String with brief description of the example.
% Nsl .......... Number of slides in example (MUST BE AT LEAST TWO.)
% Nra .......... Number of rays that will be plotted.
% xmin ......... Lower axis limit for x.
% xmax ......... Upper axis limit for x.
% ymin ......... Lower axis limit for y.
% ymax ......... Upper axis limit for y.
% X ............ Nsl by something array. Row n has the x-coordinates
%                for the wave front at a time given in T(n).
% Y ............ Nsl by something array. Row n has the x-coordinates
%                for the wave front at a time given in T(n).
% T ............ 1 by Nsl array. Times the wave-front was computed. T(1) = 0.
% xe ........... x-coordinates for the envelope of rays.
% ye ........... y-coordinates for the envelope of rays.
% xray ......... 1 by Nra array: x-coordinates on t=0 wavefront (for a ray.)
% yray ......... 1 by Nra array: y-coordinates on t=0 wavefront (for a ray.)
% norx ......... 1 by Nra array \ (norx(n), nory(n)) = unit normal to t=0
% nory ......... 1 by Nra array / wavefront at (xray(n), yray(n)).
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright 2001-2008 Massachusetts Institute of Technology
% Version 01 by Rodolfo R. Rosales  02-15-2001.
% Update     by Rodolfo R. Rosales  03-15-2008.
% 
% Permission is hereby granted, without payment, to copy this software
% and its documentation, if any,  for non-profit academic and research
% purposes,  provided that the above copyright notice, this paragraph,
% and the following three paragraphs appear in all copies of this
% software. Use of this software constitutes acceptance of these terms
% and conditions.
%
% IN NO EVENT SHALL MIT, OR THE AUTHOR, BE LIABLE TO ANY PARTY FOR
% DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
% ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN
% IF MIT, OR THE AUTHOR, HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH
% DAMAGE.
%
% MIT, AND THE AUTHOR, SPECIFICALLY DISCLAIM ANY EXPRESS OR IMPLIED
% WARRANTIES INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
% MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
% NON-INFRINGEMENT.
%
% THIS SOFTWARE IS PROVIDED "AS IS." MIT, OR THE AUTHOR, HAVE NO
% OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS,
% OR MODIFICATIONS.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
exa  = 'Example 06.';
txt  = 'Focusing ellipse, t = 0 wavefront:  x^2 + (y/0.80)^2 = 1.';
a    = 1.00;% --- Write ellipse as: (x/a)^2 + (y/b)^2 = 1.
b    = 0.80;% --- Write ellipse as: (x/a)^2 + (y/b)^2 = 1.
Nsl  =   41;% --- Number of times to plot wave-front, including t = 0.
t_f  = 2.00;% --- Final time to compute wave-front.
xmin = - 1.25;
xmax = + 1.25;
ymin = - 1.25;
ymax = + 1.25;
%
if nargin == 1
   if N == 0;   fprintf(['\n --- ', exa, ' ', txt]);   end;   return
end
%
% --- Make wave-fronts.
%
smax = 0.00;   smin = 2*pi;
s = smin + (smax-smin)*(0:200)/200;% --- parameter along wave-fronts.
T = t_f*(0:Nsl-1)/(Nsl-1);% ------------ times for wave-fronts.
D = 1./sqrt((b^2)*(cos(s).^2)+(a^2)*(sin(s).^2));
%
for n=1:Nsl
   X(n, :) = (a - b*T(n).*D).*cos(s);
   Y(n, :) = (b - a*T(n).*D).*sin(s);
end
%
% --- Make envelope.
%
xe = ((a^2-b^2)/a)*(cos(s)).^3;
ye = ((b^2-a^2)/b)*(sin(s)).^3;
%
% --- Make rays.
%
sray = 2*pi*(0:12)/12;
D    = 1./sqrt((b^2)*(cos(sray).^2)+(a^2)*(sin(sray).^2));
xray = a*cos(sray);
norx = - b*D.*cos(sray);
yray = b*sin(sray);
nory = - a*D.*sin(sray);
%
% ____________________________________________________________________________
% --- Store stuff for output. %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Output.xmin = xmin;   Output.xray = xray;   Output.exa = exa;
Output.xmax = xmax;   Output.yray = yray;   Output.Nra = length(xray);
Output.ymin = ymin;   Output.norx = norx;   Output.Nsl = Nsl;
Output.ymax = ymax;   Output.nory = nory;   Output.txt = txt;
%
Output.X = X;  Output.Y = Y;  Output.T = T;  Output.xe = xe;  Output.ye = ye;
%
if nargout == 0; clear Output; end
%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%% EOF


